@@ -25,6 +25,6 @@ class Theme:
 
     def _read_partials(self):
         result = {}
-        for partial in self.path.glob('*_partial.html'):
-            result[partial.name[:-10]] = partial.read_text()
+        for partial in self.path.glob('*.html'):
+            result[partial.name[:-5]] = partial.read_text()
         return result
